#!/usr/bin/env bash
#* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
#*                                                                           *
#*    This file is part of the test engine for the 11th DIMACS challenge     *
#*                                                                           *
#* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

EVALFILE=$1

# construct paths
SCRIPTPATH=`pwd`
TSTPATH=$SCRIPTPATH/testsets
BENCHPATH=$SCRIPTPATH/bench
SOLUTIONPATH=$SCRIPTPATH/results/solutions

NAME=`basename $EVALFILE .eval`
DIR=`dirname $EVALFILE`
OUTFILE=$DIR/$NAME.out
RESFILE=$DIR/$NAME.res
TMPFILE=$DIR/$NAME.tmp

TSTNAME=`echo $NAME | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-.]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)/\1/g'`
SOLVER=`echo $NAME | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-.]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)/\2/g'`
THREADS=`echo $NAME | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-.]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)/\3/g'`
TIME=`echo $NAME | sed 's/\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-.]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)\.\([a-zA-Z0-9_-][a-zA-Z0-9_-]*\)/\4/g'`

echo > $TMPFILE

SOLUFILE=$TSTPATH/$TSTNAME.solu
# check if a solution  file/link exists
if test ! -e $SOLUFILE
then
    echo "Warning: solution file/link <$TSTNAME.solu> does not exist in <testsets> folder; therefore, no consistency check and primal integral computation"
    SOLUFILE=""
fi


# loop over all instance names which are listed in the test set file name
for i in `cat $EVALFILE`
do
    # check if the current solution file exists
    if test -f $i
    then
	INSTANCE=`basename $i .sol`
	INSTANCE=`echo $INSTANCE | sed 's/\([a-zA-Z0-9_-]*\).\([a-zA-Z0-9_-]*\).*/\2/g'`

	echo @01 $INSTANCE =========== >> $TMPFILE

	SOLFILE=$i

	cat $SOLFILE >> $TMPFILE

	echo =ready= >> $TMPFILE
    else
	echo "file $i missing"
    fi
done

awk -f scripts/parse.awk $BENCHPATH/score.log $SOLUFILE $TMPFILE | tee $RESFILE
